@@ -117,9 +117,7 @@ export function addActionEventListener(component, eventType) {
         const { action } = actionEvent;
         const { element } = actionEvent;
 
-        // TOD: Check why the targetElement needs to check isSameNode OR has the same
-        // key/id since `isSameNode` won't always work
-        if (targetElement.isSame(element) || targetElement.isSameId(element)) {
+        if (targetElement.isSame(element)) {
           // Add the value of any child element of the target that is a lazy model to the action queue
           // Handles situations similar to https://github.com/livewire/livewire/issues/528
           component.walker(element.el, (childEl) => {
